From 0de05499eddd2afbd69b5f247d4cffdee448db19 Mon Sep 17 00:00:00 2001
From: Aleric Inglewood <Aleric.Inglewood@gmail.com>
Date: Wed, 15 Dec 2010 17:40:22 +0100
Subject: [PATCH] VWR-24247: develop.py configure still searches for the wrong
 header file when checking for Tut

The viewer code includes "tut/tut.hpp" everywhere, so that is what we
should search for when determining an include path for this header.
This just searches in the usual places, including the paths provided
through CMAKE_INCLUDE_PATH, and will find tut/tut.hpp: exactly what
we need.
---
 doc/contributions.txt     | 1 +
 indra/cmake/FindTut.cmake | 7 +++----
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/doc/contributions.txt b/doc/contributions.txt
index 3f080dfb6d2..511ed0db9fe 100644
--- a/doc/contributions.txt
+++ b/doc/contributions.txt
@@ -72,6 +72,7 @@ Aleric Inglewood
 	VWR-12984
 	VWR-13996
 	VWR-14426
+	VWR-24247
 	SNOW-84
 	SNOW-477
 	SNOW-744
diff --git a/indra/cmake/FindTut.cmake b/indra/cmake/FindTut.cmake
index b5d58f6396e..c2a9f430534 100644
--- a/indra/cmake/FindTut.cmake
+++ b/indra/cmake/FindTut.cmake
@@ -3,12 +3,11 @@
 # - Find Tut
 # Find the Tut unit test framework includes and library
 # This module defines
 #  TUT_INCLUDE_DIR, where to find tut.h, etc.
 #  TUT_FOUND, If false, do not try to use Tut.
 
-find_path(TUT_INCLUDE_DIR tut.h
-    /usr/local/include/
-    /usr/include
+find_path(TUT_INCLUDE_DIR tut/tut.hpp
+    NO_SYSTEM_ENVIRONMENT_PATH
     )
 
 if (TUT_INCLUDE_DIR)
@@ -3,12 +3,11 @@
 # Find the Tut unit test framework includes and library
 # This module defines
-#  TUT_INCLUDE_DIR, where to find tut.h, etc.
+#  TUT_INCLUDE_DIR, where to find tut/tut.hpp.
 #  TUT_FOUND, If false, do not try to use Tut.
 
-- 
GitLab